==> lachesis-0.2.2.tar.gz: lachesis-0.2.2/cmd/actions.cc <==
/*
 * Lachesis, an IRCRPG combat engine - Bot action command handler.
 * Copyright 2002 M. Dennis
 *
 * This program is free software; please see the file COPYING for details.
 * Note: This acts as the root command handler for RPGServ.
 */

#include <string.h>
#include <stdio.h>
#include "root.h"
#include "actions.h"
#ifdef RPGSERV
#include "authcmd.h"
#include "channel.h"
#include "logcmd.h"
#include "roll.h"
#endif
#include "../ircint.h"
#include "../lachesis.h"
#include "../utils.h"
#include "../auth.h"

extern char *irc_curchan;

#ifndef RPGSERV
extern Cmd_PMod cmd_modules;

void Cmd_actions_Init()
{
  Cmd_Alloc(&Cmd_Actions_Root, "do", CMD_AUTH_MASTER);
}
#else
void Cmd_Init()
{
}

void Cmd_Cleanup()
{
}
#endif

#ifdef RPGSERV
void Cmd_Root(void *ticket, int auth, const char *str)
{
#else
void Cmd_Actions_Root(void *ticket, int auth, const char *str)
{
#endif
  const char *data, *cmd;
  data = str;

  if (str==NULL) {
    Auth_CmdResult(ticket, auth,
		   "Usage: do {say|action|msg|notice|nick|chan|quote|quit}");
    return ;
  }
  cmd = Util_Separate(&data, 32);
  if (cmd==NULL) {
    cmd = data;
    data = NULL;
  }
#ifdef RPGSERV
  if (strcasecmp(cmd, "DO")==0) {
    Cmd_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "AUTH")==0) {
    Cmd_Auth_Root(ticket, auth, data);
    return ;
  }
  if (auth<CMD_AUTH_USER) {
    Auth_CmdResult(ticket, auth, "You are not an authorized user.");
    return ;
  }
#endif
  if (strcasecmp(cmd, "SAY")==0) {
    if (irc_curchan&&*irc_curchan)
      IRC_Public(irc_curchan, data);
    else
      Auth_CmdResult(ticket, auth, "No current channel.");
    return ;
  }
  if (strcasecmp(cmd, "ACTION")==0 || strcasecmp(cmd, "EMOTE")==0 ||
      strcasecmp(cmd, "POSE")==0 || strcasecmp(cmd, "ME")==0) {
    if (irc_curchan&&*irc_curchan)
      IRC_Action(irc_curchan, data);
    else
      Auth_CmdResult(ticket, auth, "No current channel.");
    return ;
  }
  if (strcasecmp(cmd, "NICK")==0) {
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      IRC_Nick(data);
    else
      IRC_Nick(cmd);
    return ;
  }
#ifdef RPGSERV
  if (strcasecmp(cmd, "CHANNEL")==0) {
    Cmd_Channel_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "LOG")==0) {
    if (auth<CMD_AUTH_MASTER)
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
    else
      Cmd_Log_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "ROLL")==0) {
    Cmd_Roll_Root(ticket, auth, data);
    return ;
  }
#endif
  if (strcasecmp(cmd, "MSG")==0) {
#ifdef RPGSERV
#ifdef NO_USER_MSGNOTICE
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No target provided to send!");
      return ;
    }
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      Auth_CmdResult(ticket, auth, "No message provided to send!");
    else
      IRC_MSG(cmd, data);
    return ;
  }
  if (strcasecmp(cmd, "NOTICE")==0) {
#ifdef RPGSERV
#ifdef NO_USER_MSGNOTICE
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No target provided to send!");
      return ;
    }
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      Auth_CmdResult(ticket, auth, "No message provided to send!");
    else
      IRC_Notice(cmd, data);
    return ;
  }
  if (strcasecmp(cmd, "QUOTE")==0) {
#ifdef RPGSERV
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No command provided to send!");
      return ;
    }
    IRC_Quote(data, FALSE);
    return ;
  }
  if (strcasecmp(cmd, "QUIT")==0 || strcasecmp(cmd, "DIE")==0 ||
      strcasecmp(cmd, "EXIT")==0 || strcasecmp(cmd, "SIGNOFF")==0) {
#ifdef RPGSERV
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
    if (data!=NULL)
      IRC_Quit(data);
    else
#ifdef RPGSERV
      IRC_Quit("RPGServ shutting down.");
#else
      IRC_Quit("Lachesis shutting down.");
#endif
    Shutdown();
  }
  Auth_CmdResult(ticket, auth,
#ifdef RPGSERV
		 Util_FormatD("I do not recognize %s as a command.", cmd,
			      NULL, NULL)
#else
		 Util_FormatD("The do command tree does not contain %s.", cmd,
			      NULL, NULL)
#endif
		 );
}

==> lachesis-0.2.3.tar.gz: lachesis-0.2.3/cmd/actions.cc <==
/*
 * Lachesis, an IRCRPG combat engine - Bot action command handler.
 * Copyright 2002 M. Dennis
 *
 * This program is free software; please see the file COPYING for details.
 * Note: This acts as the root command handler for RPGServ.
 */

#include <string.h>
#include <stdio.h>
#include "root.h"
#include "actions.h"
#ifdef RPGSERV
#include "authcmd.h"
#include "channel.h"
#include "logcmd.h"
#include "roll.h"
#endif
#include "../ircint.h"
#include "../lachesis.h"
#include "../utils.h"
#include "../auth.h"
#include "../log.h"

extern char *irc_curchan;

#ifndef RPGSERV
extern Cmd_PMod cmd_modules;

void Cmd_actions_Init()
{
  Cmd_Alloc(&Cmd_Actions_Root, "do", CMD_AUTH_MASTER);
}
#else
void Cmd_Init()
{
}

void Cmd_Cleanup()
{
}
#endif

#ifdef RPGSERV
void Cmd_Root(void *ticket, int auth, const char *str)
{
#else
void Cmd_Actions_Root(void *ticket, int auth, const char *str)
{
#endif
  const char *data, *cmd;
  data = str;

  if (str==NULL) {
    Auth_CmdResult(ticket, auth,
		   "Usage: do {say|action|msg|notice|nick|chan|quote|quit}");
    return ;
  }
  cmd = Util_Separate(&data, 32);
  if (cmd==NULL) {
    cmd = data;
    data = NULL;
  }
#ifdef RPGSERV
  if (strcasecmp(cmd, "DO")==0) {
    Cmd_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "AUTH")==0) {
    Cmd_Auth_Root(ticket, auth, data);
    return ;
  }
  if (auth<CMD_AUTH_USER) {
    Auth_CmdResult(ticket, auth, "You are not an authorized user.");
    return ;
  }
#endif
  if (strcasecmp(cmd, "SAY")==0) {
    if (irc_curchan&&*irc_curchan) {
      IRC_Public(irc_curchan, data);
      Log_Public(NULL, IRC_GetNick(), data);
    }
    else
      Auth_CmdResult(ticket, auth, "No current channel.");
    return ;
  }
  if (strcasecmp(cmd, "ACTION")==0 || strcasecmp(cmd, "EMOTE")==0 ||
      strcasecmp(cmd, "POSE")==0 || strcasecmp(cmd, "ME")==0) {
    if (irc_curchan&&*irc_curchan) {
      IRC_Action(irc_curchan, data);
      Log_Action(IRC_GetNick(), data);
    }
    else
      Auth_CmdResult(ticket, auth, "No current channel.");
    return ;
  }
  if (strcasecmp(cmd, "NICK")==0) {
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      IRC_Nick(data);
    else
      IRC_Nick(cmd);
    return ;
  }
#ifdef RPGSERV
  if (strcasecmp(cmd, "CHANNEL")==0) {
    Cmd_Channel_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "LOG")==0) {
    if (auth<CMD_AUTH_MASTER)
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
    else
      Cmd_Log_Root(ticket, auth, data);
    return ;
  }
  if (strcasecmp(cmd, "ROLL")==0) {
    Cmd_Roll_Root(ticket, auth, data);
    return ;
  }
#endif
  if (strcasecmp(cmd, "MSG")==0) {
#ifdef RPGSERV
#ifdef NO_USER_MSGNOTICE
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No target provided to send!");
      return ;
    }
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      Auth_CmdResult(ticket, auth, "No message provided to send!");
    else
      IRC_MSG(cmd, data);
    return ;
  }
  if (strcasecmp(cmd, "NOTICE")==0) {
#ifdef RPGSERV
#ifdef NO_USER_MSGNOTICE
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No target provided to send!");
      return ;
    }
    cmd = Util_Separate(&data, 32);
    if (cmd==NULL)
      Auth_CmdResult(ticket, auth, "No message provided to send!");
    else
      IRC_Notice(cmd, data);
    return ;
  }
  if (strcasecmp(cmd, "QUOTE")==0) {
#ifdef RPGSERV
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
    if (data == NULL) {
      Auth_CmdResult(ticket, auth, "No command provided to send!");
      return ;
    }
    IRC_Quote(data, FALSE);
    return ;
  }
  if (strcasecmp(cmd, "QUIT")==0 || strcasecmp(cmd, "DIE")==0 ||
      strcasecmp(cmd, "EXIT")==0 || strcasecmp(cmd, "SIGNOFF")==0) {
#ifdef RPGSERV
    if (auth<CMD_AUTH_MASTER) {
      Auth_CmdResult(ticket, auth, "Access to this command is restricted.");
      return ;
    }
#endif
    if (data!=NULL)
      IRC_Quit(data);
    else
#ifdef RPGSERV
      IRC_Quit("RPGServ shutting down.");
#else
      IRC_Quit("Lachesis shutting down.");
#endif
    Shutdown();
  }
  Auth_CmdResult(ticket, auth,
#ifdef RPGSERV
		 Util_FormatD("I do not recognize %s as a command.", cmd,
			      NULL, NULL)
#else
		 Util_FormatD("The do command tree does not contain %s.", cmd,
			      NULL, NULL)
#endif
		 );
}
